==> v3.16.zip: wcs/wcs/qommon/static/js/qommon.forms.js <==
$(function() {
  $('fieldset.form-plus').addClass('closed');
  $('fieldset.form-plus legend').on('click', function() {
    $(this).parent().toggleClass('closed');
  });
  if ($('form[data-has-draft]').length == 1) {
    var last_auto_save = $('form[data-has-draft]').serialize();
    var timeout_id = null;
    function autosave() {
      var new_auto_save = $('form[data-has-draft]').serialize();
      if (last_auto_save == new_auto_save) {
        timeout_id = window.setTimeout(autosave, 5000);
        return;
      }
      $.ajax({
        type: 'POST',
        url: window.location.pathname + 'autosave',
        data: new_auto_save,
        success: function(json) {
          if (json.result == 'success') {
            last_auto_save = new_auto_save;
          }
        },
        complete: function() {
          timeout_id = window.setTimeout(autosave, 5000);
        }
      });
    }
    timeout_id = window.setTimeout(autosave, 5000);
    $('#tracking-code a').on('click', autosave);
  }
  $('.date-pick').each(function() {
    var $date_input = $(this);
    var options = Object();
    options.autoclose = true;
    options.weekStart = 1;
    options.format = $date_input.data('date-format');
    options.minView = $date_input.data('min-view');
    options.startView = $date_input.data('start-view');
    if ($date_input.data('start-date')) options.startDate = $date_input.data('start-date');
    if ($date_input.data('end-date')) options.endDate = $date_input.data('end-date');
    $date_input.datetimepicker(options);
  });
  if ($('.widget-with-error').length && $('.global-errors').length == 0) {
    var first_field_with_error = $($('.widget-with-error')[0]).find('input,textarea,select');
    if (first_field_with_error.length) {
      $(first_field_with_error)[0].focus();
    }
  }
  $(window).bind('pageshow', function(event) {
    $('form').removeClass('disabled-during-submit');
  });
  $('form button').on('click', function(event) {
    if ($(this).hasClass('download')) {
      $(this).parents('form').addClass('download-button-clicked');
    } else {
      $(this).parents('form').removeClass('download-button-clicked');
    }
    return true;
  });
  $('form').on('submit', function(event) {
    var $form = $(this);
    $form.addClass('disabled-during-submit');
    if ($form.hasClass('download-button-clicked')) {
      /* form cannot be disabled for download buttons as the user will stay on
       * the same page; enable it back after a few seconds. */
      setTimeout(function() { $form.removeClass('disabled-during-submit'); }, 3000);
    }
    return true;
  });
  var live_evaluation = null;
  $('form div[data-live-source] input, form div[data-live-source] select, form div[data-live-source] textarea').on('change keyup paste wcs:change', function() {
    var new_data = $(this).parents('form').serialize();
    if (live_evaluation) {
      live_evaluation.abort();
    }
    live_evaluation = $.ajax({
      type: 'POST',
      url: window.location.pathname + 'live',
      dataType: 'json',
      data: new_data,
      headers: {'accept': 'application/json'},
      success: function(json) {
        $.each(json.result, function(key, value) {
          var $widget = $('[data-field-id="' + key + '"]');
          if (value.visible) {
            $widget.show();
          } else {
            $widget.hide();
          }
        });
      }
    });
  });
  $('form div[data-live-source] input, form div[data-live-source] select, form div[data-live-source] textarea').trigger('change');
});

==> v3.21.zip: wcs/wcs/qommon/static/js/qommon.forms.js <==
$(function() {
  $('fieldset.form-plus').addClass('closed');
  $('fieldset.form-plus legend').on('click', function() {
    $(this).parent().toggleClass('closed');
  });
  if ($('form[data-has-draft]').length == 1) {
    var last_auto_save = $('form[data-has-draft]').serialize();
    var timeout_id = null;
    function autosave() {
      var new_auto_save = $('form[data-has-draft]').serialize();
      if (last_auto_save == new_auto_save) {
        timeout_id = window.setTimeout(autosave, 5000);
        return;
      }
      $.ajax({
        type: 'POST',
        url: window.location.pathname + 'autosave',
        data: new_auto_save,
        success: function(json) {
          if (json.result == 'success') {
            last_auto_save = new_auto_save;
          }
        },
        complete: function() {
          timeout_id = window.setTimeout(autosave, 5000);
        }
      });
    }
    timeout_id = window.setTimeout(autosave, 5000);
    $('#tracking-code a').on('click', autosave);
  }
  $('.date-pick').each(function() {
    var $date_input = $(this);
    var options = Object();
    options.autoclose = true;
    options.weekStart = 1;
    options.format = $date_input.data('date-format');
    options.minView = $date_input.data('min-view');
    options.startView = $date_input.data('start-view');
    if ($date_input.data('start-date')) options.startDate = $date_input.data('start-date');
    if ($date_input.data('end-date')) options.endDate = $date_input.data('end-date');
    $date_input.datetimepicker(options);
  });
  if ($('.widget-with-error').length && $('.global-errors').length == 0) {
    var first_field_with_error = $($('.widget-with-error')[0]).find('input,textarea,select');
    if (first_field_with_error.length) {
      $(first_field_with_error)[0].focus();
    }
  }
  $(window).bind('pageshow', function(event) {
    $('form').removeClass('disabled-during-submit');
  });
  $('form button').on('click', function(event) {
    if ($(this).hasClass('download')) {
      $(this).parents('form').addClass('download-button-clicked');
    } else {
      $(this).parents('form').removeClass('download-button-clicked');
    }
    return true;
  });
  $('form').on('submit', function(event) {
    var $form = $(this);
    $form.addClass('disabled-during-submit');
    if ($form.hasClass('download-button-clicked')) {
      /* form cannot be disabled for download buttons as the user will stay on
       * the same page; enable it back after a few seconds. */
      setTimeout(function() { $form.removeClass('disabled-during-submit'); }, 3000);
    }
    return true;
  });
  var live_evaluation = null;
  $('form div[data-live-source]').parents('form').on('wcs:change', function(ev, data) {
    if (live_evaluation) {
      live_evaluation.abort();
    }
    var new_data = $(this).serialize();
    if (data && data.modified_field) {
      new_data += '&modified_field_id=' + data.modified_field;
    }
    live_evaluation = $.ajax({
      type: 'POST',
      url: window.location.pathname + 'live',
      dataType: 'json',
      data: new_data,
      headers: {'accept': 'application/json'},
      success: function(json) {
        $.each(json.result, function(key, value) {
          var $widget = $('[data-field-id="' + key + '"]');
          if (value.visible) {
            $widget.show();
          } else {
            $widget.hide();
          }
        });
      }
    });
  });
  $('form div[data-live-source] input, form div[data-live-source] select, form div[data-live-source] textarea').on('change keyup paste wcs:change', function() {
      var modified_field = $(this).parents('[data-field-id]').data('field-id');
      $(this).parents('form').trigger('wcs:change', {modified_field: modified_field});
  });
  $('form div[data-live-source]').parents('form').trigger('wcs:change');
});
